@@ -83,6 +83,8 @@ def pressure_field(positions,frequencies,
         if not directivity_only:
             pressure_field = rayleigh(positions,areas,velocities,phases,field_points,frequencies,time)
             pressure_field = pressure_field.reshape(-1,len(x)) # It's the number of points in the x-direction that you use here
+        else:
+            pressure_field = 0
         
         # Getting the directivity at a given distance. Default is 1000 meters away
         if not dimensions == 1:
@@ -106,7 +108,7 @@ def pressure_field(positions,frequencies,
     
     # Only show plots if you calculated the entirie pressure field
     if dimensions == 1:
-        plot_1D(x,pressure_field,positions,show_plots,color_limits)
+        plot_1D(x,pressure_field,positions,show_plots,color_limits,directivity_only)
         theta = 0
         directivity = 0
 
@@ -115,17 +117,12 @@ def pressure_field(positions,frequencies,
 
     if dimensions == 3:
         plot_3D(X,Y,Z,pressure_field,positions,method,theta,directivity,show_plots,directivity_only,directivity_distance,directivity_plot_alone,color_limits)
-    
         
-        
-    if directivity_only:
-        return directivity, theta
-    else:
-        return pressure_field, directivity, theta
+    return pressure_field, directivity, theta
 
-def plot_1D(x,pressure_field,positions,show_plots,color_limits):
+def plot_1D(x,pressure_field,positions,show_plots,color_limits,directivity_only):
 
-    if show_plots:
+    if show_plots and not directivity_only:
         # Defining the figure
         fig = plt.figure()
         fig.set_size_inches(8,8)
